import { defineNuxtModule, createResolver, installModule, extendPages, addComponentsDir, addImportsDir, addPluginTemplate } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "Sections CMS",
    configKey: "sections-cms"
  },
  // Default configuration options of the Nuxt module
  defaults: {},
  async setup(_options, _nuxt) {
    const { resolve } = createResolver(import.meta.url);
    await installModule("@nuxtjs/i18n", {
      langDir: resolve("./runtime/lang"),
      locales: [
        {
          code: "en",
          file: resolve("./runtime/lang/en.json")
        },
        {
          code: "fr",
          file: resolve("./runtime/lang/fr.json")
        }
      ]
    });
    extendPages((pages) => {
      pages.push({
        name: "all",
        path: "/:pathMatch(.*)*",
        file: resolve("./runtime/pages/[...pathMatch].vue")
      });
      pages.push({
        name: "Health",
        path: "/health",
        file: resolve("./runtime/pages/health.vue")
      });
    });
    addComponentsDir({
      path: resolve("./runtime/components")
    });
    addImportsDir(resolve("./runtime/utils"), {
      prepend: true
    });
    addPluginTemplate(resolve("./runtime/plugin"));
    await installModule("@geeks.solutions/vue-components");
    _nuxt.hook("vite:extendConfig", (config) => {
      config.optimizeDeps = config.optimizeDeps || {};
      config.optimizeDeps.include = config.optimizeDeps.include || [];
      config.optimizeDeps.needsInterop = config.optimizeDeps.needsInterop || [];
      if (!config.optimizeDeps.include.includes("@marshallswain/vuedraggable")) {
        config.optimizeDeps.include.push("@marshallswain/vuedraggable");
      }
      if (!config.optimizeDeps.needsInterop.includes("@marshallswain/vuedraggable")) {
        config.optimizeDeps.needsInterop.push("@marshallswain/vuedraggable");
      }
    });
  }
});

export { module as default };
